@@ -10,7 +10,6 @@
 #ifndef E_TEXT_MODEL_URI_H
 #define E_TEXT_MODEL_URI_H
 
-#include <gnome.h>
 #include <gal/e-text/e-text-model.h>
 
 BEGIN_GNOME_DECLS
@@ -25,8 +24,10 @@ typedef struct _ETextModelURI ETextModelURI;
 typedef struct _ETextModelURIClass ETextModelURIClass;
 
 struct _ETextModelURI {
-  ETextModel item;
-  GList *uris;
+	ETextModel item;
+	GList *uris;
+	
+	guint objectify_idle;
 };
 
 struct _ETextModelURIClass {
